@@ -13,42 +13,35 @@ from mldock.api.assets import infer_filesystem_type
 
 
 click.disable_unicode_literals_warning = True
-logger = logging.getLogger('mldock')
-MLDOCK_CONFIG_NAME = 'mldock.json'
+logger = logging.getLogger("mldock")
+MLDOCK_CONFIG_NAME = "mldock.json"
+
 
 def reset_terminal():
     """clears the terminal view frame"""
     click.clear()
 
+
 @click.group()
 def logs():
     """
     Commands to manage and interact with logs.
     """
 
+
 @click.command()
-@click.option(
-    '--log-path',
-    type=str,
-    help='a grok pattern'
-)
-@click.option(
-    '--log-file',
-    type=str,
-    default='logs.txt',
-    help='file name'
-)
+@click.option("--log-path", type=str, help="a grok pattern")
+@click.option("--log-file", type=str, default="logs.txt", help="file name")
 def show(log_path, log_file):
     """show errors for all runs as a table"""
 
-
     file_system, log_path = infer_filesystem_type(log_path)
 
     logs_data = get_all_file_objects(log_path, log_file, file_system)
 
     log_runs = [Path(log).parents[0].name for log in logs_data]
 
-    state = choice('Select a run', log_runs, default=None)
+    state = choice("Select a run", log_runs, default=None)
 
     for log in logs_data:
         if Path(log).parents[0].name == state:
@@ -60,11 +53,12 @@ def show(log_path, log_file):
     reset_terminal()
     print(log_data)
 
+
 def add_commands(cli_group: click.group):
     """
-        add commands to cli group
-        args:
-            cli (click.group)
+    add commands to cli group
+    args:
+        cli (click.group)
     """
     cli_group.add_command(show)
     cli_group.add_command(metrics_commands)
@@ -72,4 +66,5 @@ def add_commands(cli_group: click.group):
     cli_group.add_command(grok)
     cli_group.add_command(errors)
 
+
 add_commands(logs)
