@@ -9,8 +9,8 @@ from mldock.api.logs import parse_grok_multiline, get_all_file_objects
 from mldock.api.assets import infer_filesystem_type
 
 click.disable_unicode_literals_warning = True
-logger = logging.getLogger('mldock')
-MLDOCK_CONFIG_NAME = 'mldock.json'
+logger = logging.getLogger("mldock")
+MLDOCK_CONFIG_NAME = "mldock.yaml"
 
 
 @click.group()
@@ -19,23 +19,11 @@ def grok():
     Commands to manage and interact with logs using grok.
     """
 
+
 @click.command()
-@click.option(
-    '--log-path',
-    type=str,
-    help='a grok pattern'
-)
-@click.option(
-    '--log-file',
-    type=str,
-    default='logs.txt',
-    help='file name'
-)
-@click.option(
-    '--pattern',
-    type=str,
-    help='a grok pattern'
-)
+@click.option("--log-path", type=str, help="a grok pattern")
+@click.option("--log-file", type=str, default="logs.txt", help="file name")
+@click.option("--pattern", type=str, help="a grok pattern")
 def parse(log_path, log_file, pattern):
     """parse logs using a custom crok config and show"""
 
@@ -45,7 +33,7 @@ def parse(log_path, log_file, pattern):
 
     log_runs = [Path(log).parents[0].name for log in logs]
 
-    state = choice('Select a run', log_runs, default=None)
+    state = choice("Select a run", log_runs, default=None)
 
     for log in logs:
         if Path(log).parents[0].name == state:
@@ -56,4 +44,5 @@ def parse(log_path, log_file, pattern):
 
     print(json.dumps(metadata, indent=4, sort_keys=True))
 
+
 grok.add_command(parse)
