@@ -13,20 +13,16 @@ from mldock.terminal import ChoiceWithNumbers, style_dropdown
 from mldock.config_managers.core import BaseConfigManager
 from mldock.platform_helpers import utils
 
-logger = logging.getLogger('mldock')
-MLDOCK_CLI_CONFIG="./.mldock/config"
+logger = logging.getLogger("mldock")
+MLDOCK_CLI_CONFIG = "./.mldock/config"
+
 
 class CliConfigureManager(BaseConfigManager):
-    """CLI Configure Manager for mldock
-    """
+    """CLI Configure Manager for mldock"""
 
     config = {}
 
-    def __init__(
-        self,
-        filepath: str = MLDOCK_CLI_CONFIG,
-        create: bool = False
-    ):
+    def __init__(self, filepath: str = MLDOCK_CLI_CONFIG, create: bool = False):
         super().__init__()
         self.filepath = filepath
 
@@ -34,7 +30,7 @@ class CliConfigureManager(BaseConfigManager):
 
     def reset(self, config_type):
         """reset given configuration by config key"""
-        click.secho("Dropping {} configuration".format(config_type), bg='blue')
+        click.secho("Dropping {} configuration".format(config_type), bg="blue")
         self.config.pop(config_type, None)
 
     def check_if_exists_else_create(self, file_name: str, create: bool):
@@ -42,145 +38,133 @@ class CliConfigureManager(BaseConfigManager):
         if not self.file_exists(file_name):
             if create:
                 # deal with possiblity of nested directory
-                utils._mkdir(Path(file_name).parents[0])
+                utils.mkdir(Path(file_name).parents[0])
                 # create file
                 self.touch(file_name)
             else:
-                logger.error((
-                    "No MLDOCK CLI config found at '{CONFIG_PATH}/'. "
-                    "To create run: 'mldock configure init'".format(
-                        CONFIG_PATH=Path(file_name).parents[0]
+                logger.error(
+                    (
+                        "No MLDOCK CLI config found at '{CONFIG_PATH}/'. "
+                        "To create run: 'mldock configure init'".format(
+                            CONFIG_PATH=Path(file_name).parents[0]
+                        )
                     )
-                ))
+                )
                 sys.exit(1)
 
     def setup_local_config(self):
         """setup and prompt user for local configuration"""
-        click.secho("Setup local CLI configuration", bg='blue')
-        if self.config.get('local') is None:
-            self.config['local'] = {}
+        click.secho("Setup local CLI configuration", bg="blue")
+        if self.config.get("local") is None:
+            self.config["local"] = {}
         self.ask_for_container_auth_type()
-        self.ask_for_environment(config_type='local')
+        self.ask_for_environment(config_type="local")
 
     def setup_templates_config(self):
         """setup and prompt user for templates configuration"""
-        click.secho("Setup templates CLI configuration", bg='blue')
-        if self.config.get('templates') is None:
-            self.config['templates'] = {}
+        click.secho("Setup templates CLI configuration", bg="blue")
+        if self.config.get("templates") is None:
+            self.config["templates"] = {}
         self.ask_for_template_server()
         self.ask_for_template_root()
 
     def setup_remotes_config(self):
         """setup and prompt user for templates configuration"""
-        click.secho("Setup remotes CLI configuration", bg='blue')
-        if self.config.get('remotes') is None:
-            self.config['remotes'] = []
+        click.secho("Setup remotes CLI configuration", bg="blue")
+        if self.config.get("remotes") is None:
+            self.config["remotes"] = []
         self.ask_for_remote_path()
 
     def setup_workspace_config(self):
         """setup and prompt user for workspace configuration"""
-        click.secho("Setup workspace CLI configuration", bg='blue')
-        if self.config.get('workspace') is None:
-            self.config['workspace'] = {}
-        self.ask_for_environment(config_type='workspace')
+        click.secho("Setup workspace CLI configuration", bg="blue")
+        if self.config.get("workspace") is None:
+            self.config["workspace"] = {}
+        self.ask_for_environment(config_type="workspace")
 
     def ask_for_container_auth_type(self):
-        """prompt user for platform name
-        """
+        """prompt user for platform name"""
 
-        click.secho("Set local authentication type", bg='blue', nl=True)
-        options = ['gcloud', 'awscli']
+        click.secho("Set local authentication type", bg="blue", nl=True)
+        options = ["gcloud", "awscli"]
 
         auth_type = click.prompt(
             text=style_dropdown(
                 group_name="authentication type",
                 options=options,
-                default=self.config.get('auth_type', None)
+                default=self.config.get("auth_type", None),
             ),
             type=ChoiceWithNumbers(options, case_sensitive=False),
             show_default=True,
-            default=self.config.get('auth_type', None),
-            show_choices=False
+            default=self.config.get("auth_type", None),
+            show_choices=False,
         )
 
-        self.config['local'].update({
-            'auth_type': auth_type
-        })
+        self.config["local"].update({"auth_type": auth_type})
 
     def ask_for_environment(self, config_type):
         """
-            prompt user for environment variables
+        prompt user for environment variables
 
-            args:
-                config_type (str): config key that points to configure config type
+        args:
+            config_type (str): config key that points to configure config type
         """
-        config = self.config[config_type].get('environment', {})
+        config = self.config[config_type].get("environment", {})
         environment_config_manager = EnvironmentConfigManager(config=config)
         environment_config_manager.ask_for_env_vars()
-        self.config[config_type].update({
-            'environment': environment_config_manager.get_config()
-        })
+        self.config[config_type].update(
+            {"environment": environment_config_manager.get_config()}
+        )
 
     def ask_for_template_server(self):
-        """prompt user to set template server tracking
-        """
+        """prompt user to set template server tracking"""
 
-        click.secho("Set template server type", bg='blue', nl=True)
-        options = ['local', 'github']
+        click.secho("Set template server type", bg="blue", nl=True)
+        options = ["local", "github"]
 
         server_type = click.prompt(
             text=style_dropdown(
                 group_name="template server type",
                 options=options,
-                default=self.config.get('server_type', None)
+                default=self.config.get("server_type", None),
             ),
             type=ChoiceWithNumbers(options, case_sensitive=False),
             show_default=True,
-            default=self.config.get('server_type', None),
-            show_choices=False
+            default=self.config.get("server_type", None),
+            show_choices=False,
         )
 
-        self.config['templates'].update({
-            'server_type': server_type
-        })
+        self.config["templates"].update({"server_type": server_type})
 
     def ask_for_template_root(self):
-        """prompt user to set template root
-        """
+        """prompt user to set template root"""
 
-        click.secho("Set template root", bg='blue', nl=True)
+        click.secho("Set template root", bg="blue", nl=True)
 
         templates_root_dir = click.prompt(
-            text=click.style("Set path to template root dir: ", fg='bright_blue'),
-            default=self.config['templates'].get('templates_root', None)
+            text=click.style("Set path to template root dir: ", fg="bright_blue"),
+            default=self.config["templates"].get("templates_root", None),
         )
 
-        self.config['templates'].update({
-            'templates_root': templates_root_dir
-        })
+        self.config["templates"].update({"templates_root": templates_root_dir})
 
     def ask_for_remote_path(self):
-        """prompt user to set template root
-        """
+        """prompt user to set template root"""
 
-        click.secho("Set remote path", bg='blue', nl=True)
+        click.secho("Set remote path", bg="blue", nl=True)
 
         remote_path = click.prompt(
-            text=click.style("Set path to remote: ", fg='bright_blue')
+            text=click.style("Set path to remote: ", fg="bright_blue")
         )
 
         _, path = utils.get_bucket_and_path_from_scheme(remote_path)
         name = path.replace("/", " ").strip().replace(" ", ":")
         scheme = utils.get_scheme(remote_path)
 
-        remotes_manager = RemotesConfigManager(config=self.config.get('remotes', []))
+        remotes_manager = RemotesConfigManager(config=self.config.get("remotes", []))
 
-        remotes_manager.add_remote(
-            name=name,
-            type=scheme,
-            path=remote_path
-        )
-        self.config['remotes'] = remotes_manager.get_config()
+        remotes_manager.add_remote(name=name, type=scheme, path=remote_path)
+        self.config["remotes"] = remotes_manager.get_config()
 
     @staticmethod
     def _format_nodes(config):
@@ -191,15 +175,12 @@ class CliConfigureManager(BaseConfigManager):
             value_ = config[key_]
             if isinstance(value_, dict):
                 value_ = yaml.dump(value_, indent=4, sort_keys=True)
-            output.append({
-                "name": key_, "message": value_
-            })
+            output.append({"name": key_, "message": value_})
 
         return output
 
     def get_state(self):
-        """pretty prints a json config to terminal
-        """
+        """pretty prints a json config to terminal"""
         config = self.config.copy()
 
         states = self._format_nodes(config)
@@ -213,7 +194,7 @@ class CliConfigureManager(BaseConfigManager):
         Returns:
             dict: config
         """
-        return self.config.get('local', {})
+        return self.config.get("local", {})
 
     @property
     def workspace(self) -> dict:
@@ -222,7 +203,7 @@ class CliConfigureManager(BaseConfigManager):
         Returns:
             dict: config
         """
-        return self.config.get('workspace', {})
+        return self.config.get("workspace", {})
 
     @property
     def templates(self) -> dict:
@@ -231,7 +212,7 @@ class CliConfigureManager(BaseConfigManager):
         Returns:
             dict: config
         """
-        return self.config.get('templates', {})
+        return self.config.get("templates", {})
 
     @property
     def remotes(self) -> dict:
@@ -241,20 +222,13 @@ class CliConfigureManager(BaseConfigManager):
             dict: config
         """
 
-        return RemotesConfigManager(
-            config=self.config.get('remotes', {})
-        )
+        return RemotesConfigManager(config=self.config.get("remotes", {}))
 
 
 class PackageConfigManager(BaseConfigManager):
-    """Package Requirement Config Manager for sagify
-    """
+    """Package Requirement Config Manager for sagify"""
 
-    def __init__(
-        self,
-        filepath: str,
-        create: bool = False
-    ):
+    def __init__(self, filepath: str, create: bool = False):
         super().__init__()
         self.filepath = filepath
 
@@ -278,9 +252,7 @@ class PackageConfigManager(BaseConfigManager):
         Returns:
             list: config
         """
-        self.check_if_exists_else_create(
-            file_name=file_name, create=create
-        )
+        self.check_if_exists_else_create(file_name=file_name, create=create)
         path = Path(file_name)
         with path.open() as file_:
             config = file_.readlines()
@@ -310,9 +282,8 @@ class PackageConfigManager(BaseConfigManager):
                     self.config.append(new_package)
 
     def pretty_print(self):
-        """pretty prints a list config to terminal
-        """
-        pretty_config = json.dumps(self.config, indent=4, separators=(',', ': '))
+        """pretty prints a list config to terminal"""
+        pretty_config = json.dumps(self.config, indent=4, separators=(",", ": "))
         logger.debug("{}\n".format(pretty_config))
 
     def write_file(self):
@@ -323,58 +294,93 @@ class PackageConfigManager(BaseConfigManager):
         config_txt = "\n".join(config) + "\n"
         Path(self.filepath).write_text(config_txt)
 
+
 class StageConfigManager(BaseConfigManager):
-    """Development Stage Config Manager for mldock
-    """
+    """Development Stage Config Manager for mldock"""
 
     def __init__(self, config: dict):
         self.config = config
 
     def ask_for_stages(self):
-        """prompt user for stages
-        """
-        click.secho("Stages", bg='blue', nl=True)
+        """prompt user for stages"""
+        click.secho("Stages", bg="blue", nl=True)
         while True:
-            echo_msg = click.style(
-                "Add a development stage. ",
-                fg='bright_blue'
-            ) + "(Follow the prompts)"
-
-            click.echo(
-                echo_msg,
-                nl=True
+            echo_msg = (
+                click.style("Add a development stage. ", fg="bright_blue")
+                + "(Follow the prompts)"
             )
 
+            click.echo(echo_msg, nl=True)
+
             stage_name = click.prompt(
-                text="Stage name: ",
-                default="end",
-                show_default=False,
-                type=str
+                text="Stage name: ", default="end", show_default=False, type=str
             )
             if stage_name == "end":
                 break
 
             docker_tag = click.prompt(
                 text="Set docker image tag: ",
-                default=self.config.get(stage_name, {}).get('tag', None)
+                default=self.config.get(stage_name, {}).get("tag", None),
             )
             if stage_name not in self.config:
                 self.config[stage_name] = {}
 
-            self.config[stage_name].update(
-                {'tag': docker_tag}
+            self.config[stage_name].update({"tag": docker_tag})
+
+class RoutinesConfigManager(BaseConfigManager):
+    """Development Routines Config Manager for mldock"""
+
+    def __init__(self, config: dict):
+        self.config = config
+
+    def ask_for_routines(self):
+        """prompt user for routines"""
+        click.secho("Routines", bg="blue", nl=True)
+        while True:
+            echo_msg = (
+                click.style("Add a routine. ", fg="bright_blue")
+                + "(Follow the prompts)"
             )
 
+            click.echo(echo_msg, nl=True)
+
+            routine_name = click.prompt(
+                text="Routine name: ", default="end", show_default=False, type=str
+            )
+            if routine_name == "end":
+                break
+
+            # format routine name
+            routine_name = routine_name.replace(" ", "_").replace("-", "_").replace(".", "_")
+
+            if routine_name not in self.config:
+                self.config[routine_name] = []
+
+            while True:
+                echo_msg = (
+                    click.style("Add a step to the routine. ", fg="bright_blue")
+                    + "(any terminal or bash command)"
+                )
+
+                click.echo(echo_msg, nl=True)
+
+                routine_step = click.prompt(
+                    text="add command: ", default="end", show_default=False, type=str
+                )
+                if routine_step == "end":
+                    break
+                # add
+                self.config[routine_name].append(routine_step)
+
 class HyperparameterConfigManager(BaseConfigManager):
-    """Hyperparameter Config Manager for mldock
-    """
+    """Hyperparameter Config Manager for mldock"""
 
     def __init__(self, config: dict):
         self.config = config
 
     @staticmethod
     def is_float(value):
-        """ Returns True is string is a number. """
+        """Returns True is string is a number."""
         try:
             float(value)
             return True
@@ -382,48 +388,42 @@ class HyperparameterConfigManager(BaseConfigManager):
             return False
 
     def ask_for_hyperparameters(self):
-        """prompt user for hyperparameters
-        """
-        click.secho("Hyperparameters", bg='blue', nl=True)
+        """prompt user for hyperparameters"""
+        click.secho("Hyperparameters", bg="blue", nl=True)
         while True:
 
-            echo_msg = click.style(
-                "Add a hyperparameter. ",
-                fg='bright_blue'
-            )+"(Follow prompts)"
-
-            click.echo(
-                echo_msg,
-                nl=True
+            echo_msg = (
+                click.style("Add a hyperparameter. ", fg="bright_blue")
+                + "(Follow prompts)"
             )
+
+            click.echo(echo_msg, nl=True)
             hparam_name = click.prompt(
                 text="Hyperparameter (name): ",
                 default="end",
                 show_default=False,
-                type=str
+                type=str,
             )
 
             if hparam_name == "end":
                 break
 
             hparam_value = click.prompt(
-                text="Set value: ",
-                default=self.config.get(hparam_name, None)
+                text="Set value: ", default=self.config.get(hparam_name, None)
             )
 
-            self.config.update(
-                {hparam_name: hparam_value}
-            )
+            self.config.update({hparam_name: hparam_value})
+
 
 class EnvironmentConfigManager(BaseConfigManager):
-    """Environment Config Manager for mldock
-    """
+    """Environment Config Manager for mldock"""
+
     def __init__(self, config: dict):
         self.config = config
 
     @staticmethod
     def is_float(value):
-        """ Returns True is string is a number. """
+        """Returns True is string is a number."""
         try:
             float(value)
             return True
@@ -432,51 +432,46 @@ class EnvironmentConfigManager(BaseConfigManager):
 
     @staticmethod
     def parse_bool(value):
-        """ Returns True is string is a bool. """
+        """Returns True is string is a bool."""
         result = value
-        if value.lower() == 'true':
+        if value.lower() == "true":
             result = True
-        elif value.lower() == 'false':
+        elif value.lower() == "false":
             result = False
         return result
 
     def ask_for_env_vars(self):
-        """prompt user for environment variables
-        """
-        click.secho("Environment Variables", bg='blue', nl=True)
+        """prompt user for environment variables"""
+        click.secho("Environment Variables", bg="blue", nl=True)
         while True:
-            echo_msg = click.style(
-                "Add a environment variable. ",
-                fg='bright_blue'
-            ) + "(Follow prompts)"
-
-            click.echo(
-                echo_msg,
-                nl=True
+            echo_msg = (
+                click.style("Add a environment variable. ", fg="bright_blue")
+                + "(Follow prompts)"
             )
 
+            click.echo(echo_msg, nl=True)
+
             env_var_name = click.prompt(
                 text="Environment Variable (name): ",
                 default="end",
                 show_default=False,
-                type=str
+                type=str,
             )
             if env_var_name == "end":
                 break
 
             env_var_value = click.prompt(
-                text="Set value: ",
-                default=self.config.get(env_var_name, None)
+                text="Set value: ", default=self.config.get(env_var_name, None)
             )
 
-            self.config.update(
-                {env_var_name: env_var_value}
-            )
+            self.config.update({env_var_name: env_var_value})
+
 
 class InputDataConfigManager(BaseConfigManager):
-    """InputData Config Manager for mldock
-    """
+    """InputData Config Manager for mldock"""
+
     file_ignores = []
+
     def __init__(self, config: dict, base_path: str):
         self.config = config
         self.base_path = base_path
@@ -486,13 +481,13 @@ class InputDataConfigManager(BaseConfigManager):
         write to file
         """
         config = {
-            Path(dataset['channel'], dataset['filename']).as_posix()
+            Path(dataset["channel"], dataset["filename"]).as_posix()
             for dataset in self.config
         }
 
         config_txt = "\n".join(config) + "\n"
 
-        ignore_filepath = Path(self.base_path,".gitignore")
+        ignore_filepath = Path(self.base_path, ".gitignore")
         Path(ignore_filepath).write_text(config_txt)
 
     def check_if_asset_exists(self, channel, filename):
@@ -501,36 +496,46 @@ class InputDataConfigManager(BaseConfigManager):
         for i in range(len(self.config)):
             tmp_config = self.config[i]
 
-            if (
-                (
-                    tmp_config['channel'] == channel
-                ) and (
-                    tmp_config['filename'] == filename
-                )
+            if (tmp_config["channel"] == channel) and (
+                tmp_config["filename"] == filename
             ):
                 # pop the current config
                 found_match = True
-        
+
                 return found_match, i
         return False, None
-        
+
+    def find_all_for_given_channel(self, channel):
+
+        datasets = []
+        for i in range(len(self.config)):
+            tmp_config = self.config[i]
+
+            if (tmp_config["channel"] == channel):
+
+                datasets.append(tmp_config)
+
+        return datasets
+
     def add_asset(self, update: bool = False, **data_config):
         """add an asset to data config"""
 
-
         found_match, i = self.check_if_asset_exists(
-            channel=data_config.get('channel'),
-            filename=data_config.get('filename')
+            channel=data_config.get("channel"), filename=data_config.get("filename")
         )
 
-        if (update==False) and found_match:
-            logger.error("dataset artifact already exists. To update, run 'datasets update' instead.")
+        if (update == False) and found_match:
+            logger.error(
+                "dataset artifact already exists. To update, run 'datasets update' instead."
+            )
             exit(0)
         elif update and found_match:
             current_config = self.config.pop(i)
             current_config.update(data_config)
         elif update and (found_match == False):
-            logger.error("dataset artifact does not exists. To create, run 'datasets create' instead.")
+            logger.error(
+                "dataset artifact does not exists. To create, run 'datasets create' instead."
+            )
             exit(0)
         else:
             current_config = data_config
@@ -539,8 +544,7 @@ class InputDataConfigManager(BaseConfigManager):
 
     def remove(self, **data_config):
         found_match, i = self.check_if_asset_exists(
-            channel=data_config.get('channel'),
-            filename=data_config.get('filename')
+            channel=data_config.get("channel"), filename=data_config.get("filename")
         )
 
         if found_match:
@@ -550,32 +554,42 @@ class InputDataConfigManager(BaseConfigManager):
 
     def get(self, **data_config):
         found_match, i = self.check_if_asset_exists(
-            channel=data_config['channel'],
-            filename=data_config['filename']
+            channel=data_config["channel"], filename=data_config["filename"]
         )
 
         if found_match:
             return self.config[i]
         else:
-            logger.error("dataset artifact does not exists. To create, run 'datasets create' instead.")
+            logger.error(
+                "dataset artifact does not exists. To create, run 'datasets create' instead."
+            )
+            exit(0)
+
+    def get_all(self, **data_config):
+        datasets = self.find_all_for_given_channel(
+            channel=data_config["channel"]
+        )
+
+        if len(datasets) > 0:
+            return datasets
+        else:
+            logger.error(
+                "dataset artifact does not exists. To create, run 'datasets create' instead."
+            )
             exit(0)
 
     def ask_for_input_data_channels(self):
-        """prompt user for hyperparameters
-        """
-        click.secho("Input Data Channels", bg='blue', nl=True)
+        """prompt user for hyperparameters"""
+        click.secho("Input Data Channels", bg="blue", nl=True)
         while True:
 
-            echo_msg = click.style(
-                "Add a data channel. ",
-                fg='bright_blue'
-            ) + "(Expects channel/filename). Hit enter to continue."
+            echo_msg = (
+                click.style("Add a data channel. ", fg="bright_blue")
+                + "(Expects channel/filename). Hit enter to continue."
+            )
 
             channel_filename_pair = click.prompt(
-                text=echo_msg,
-                default="end",
-                show_default=False,
-                type=str
+                text=echo_msg, default="end", show_default=False, type=str
             )
 
             # pylint: disable=no-else-break
@@ -587,29 +601,32 @@ class InputDataConfigManager(BaseConfigManager):
 
                 break
 
-            elif "/" in channel_filename_pair and channel_filename_pair != 'channel/filename':
+            elif (
+                "/" in channel_filename_pair
+                and channel_filename_pair != "channel/filename"
+            ):
 
                 channel, filename = channel_filename_pair.split("/", 1)
 
-                logger.debug((
-                    "Adding data/{CHANNEL}/{FILE_NAME}".format(
-                        CHANNEL=channel,
-                        FILE_NAME=filename
+                logger.debug(
+                    (
+                        "Adding data/{CHANNEL}/{FILE_NAME}".format(
+                            CHANNEL=channel, FILE_NAME=filename
+                        )
                     )
-                ))
+                )
 
-                self.config.append({
-                    'channel': channel,
-                    'filename': filename
-                })
+                self.config.append({"channel": channel, "filename": filename})
 
             else:
                 logger.warning("Expected format as channel/filename. Skipping")
 
+
 class ModelConfigManager(BaseConfigManager):
-    """Model Config Manager for mldock
-    """
+    """Model Config Manager for mldock"""
+
     file_ignores = []
+
     def __init__(self, config: dict, base_path: str):
         self.config = config
         self.base_path = base_path
@@ -619,13 +636,13 @@ class ModelConfigManager(BaseConfigManager):
         write to file
         """
         config = {
-            Path(dataset['channel'], dataset['filename']).as_posix()
+            Path(dataset["channel"], dataset["filename"]).as_posix()
             for dataset in self.config
         }
 
         config_txt = "\n".join(config) + "\n"
 
-        ignore_filepath = Path(self.base_path,".gitignore")
+        ignore_filepath = Path(self.base_path, ".gitignore")
         Path(ignore_filepath).write_text(config_txt)
 
     def check_if_asset_exists(self, channel, filename):
@@ -634,36 +651,46 @@ class ModelConfigManager(BaseConfigManager):
         for i in range(len(self.config)):
             tmp_config = self.config[i]
 
-            if (
-                (
-                    tmp_config['channel'] == channel
-                ) and (
-                    tmp_config['filename'] == filename
-                )
+            if (tmp_config["channel"] == channel) and (
+                tmp_config["filename"] == filename
             ):
                 # pop the current config
                 found_match = True
-        
+
                 return found_match, i
         return False, None
-        
+
+    def find_all_for_given_channel(self, channel):
+
+        datasets = []
+        for i in range(len(self.config)):
+            tmp_config = self.config[i]
+
+            if (tmp_config["channel"] == channel):
+
+                datasets.append(tmp_config)
+
+        return datasets
+
     def add_asset(self, update: bool = False, **data_config):
         """add an asset to data config"""
 
-
         found_match, i = self.check_if_asset_exists(
-            channel=data_config.get('channel'),
-            filename=data_config.get('filename')
+            channel=data_config.get("channel"), filename=data_config.get("filename")
         )
 
-        if (update==False) and found_match:
-            logger.error("model artifact already exists. To update, run 'datasets update' instead.")
+        if (update == False) and found_match:
+            logger.error(
+                "model artifact already exists. To update, run 'datasets update' instead."
+            )
             exit(0)
         elif update and found_match:
             current_config = self.config.pop(i)
             current_config.update(data_config)
         elif update and (found_match == False):
-            logger.error("model artifact does not exists. To create, run 'models create' instead.")
+            logger.error(
+                "model artifact does not exists. To create, run 'models create' instead."
+            )
             exit(0)
         else:
             current_config = data_config
@@ -672,8 +699,7 @@ class ModelConfigManager(BaseConfigManager):
 
     def remove(self, **data_config):
         found_match, i = self.check_if_asset_exists(
-            channel=data_config.get('channel'),
-            filename=data_config.get('filename')
+            channel=data_config.get("channel"), filename=data_config.get("filename")
         )
 
         if found_match:
@@ -681,34 +707,44 @@ class ModelConfigManager(BaseConfigManager):
         else:
             logger.error("model artifact does not exists, so nothing to remove.")
 
-    def get(self, **data_config):
+    def get(self, **model_config):
         found_match, i = self.check_if_asset_exists(
-            channel=data_config['channel'],
-            filename=data_config['filename']
+            channel=model_config["channel"], filename=model_config["filename"]
         )
 
         if found_match:
             return self.config[i]
         else:
-            logger.error("model artifact does not exists. To create, run 'models create' instead.")
+            logger.error(
+                "model artifact does not exists. To create, run 'models create' instead."
+            )
+            exit(0)
+
+    def get_all(self, **model_config):
+        models = self.find_all_for_given_channel(
+            channel=model_config["channel"]
+        )
+
+        if len(models) > 0:
+            return models
+        else:
+            logger.error(
+                "dataset artifact does not exists. To create, run 'datasets create' instead."
+            )
             exit(0)
 
     def ask_for_model_channels(self):
-        """prompt user for hyperparameters
-        """
-        click.secho("Model Channels", bg='blue', nl=True)
+        """prompt user for hyperparameters"""
+        click.secho("Model Channels", bg="blue", nl=True)
         while True:
 
-            echo_msg = click.style(
-                "Add a model. ",
-                fg='bright_blue'
-            ) + "(Expects channel/filename). Hit enter to continue."
+            echo_msg = (
+                click.style("Add a model. ", fg="bright_blue")
+                + "(Expects channel/filename). Hit enter to continue."
+            )
 
             channel_filename_pair = click.prompt(
-                text=echo_msg,
-                default="end",
-                show_default=False,
-                type=str
+                text=echo_msg, default="end", show_default=False, type=str
             )
 
             # pylint: disable=no-else-break
@@ -720,29 +756,32 @@ class ModelConfigManager(BaseConfigManager):
 
                 break
 
-            elif "/" in channel_filename_pair and channel_filename_pair != 'channel/filename':
+            elif (
+                "/" in channel_filename_pair
+                and channel_filename_pair != "channel/filename"
+            ):
 
                 channel, filename = channel_filename_pair.split("/", 1)
 
-                logger.debug((
-                    "Adding model/{CHANNEL}/{FILE_NAME}".format(
-                        CHANNEL=channel,
-                        FILE_NAME=filename
+                logger.debug(
+                    (
+                        "Adding model/{CHANNEL}/{FILE_NAME}".format(
+                            CHANNEL=channel, FILE_NAME=filename
+                        )
                     )
-                ))
+                )
 
-                self.config.append({
-                    'channel': channel,
-                    'filename': filename
-                })
+                self.config.append({"channel": channel, "filename": filename})
 
             else:
                 logger.warning("Expected format as channel/filename. Skipping")
 
+
 class RemotesConfigManager(BaseConfigManager):
-    """Remotes Config Manager for mldock
-    """
+    """Remotes Config Manager for mldock"""
+
     file_ignores = []
+
     def __init__(self, config: dict):
         self.config = config
 
@@ -752,31 +791,33 @@ class RemotesConfigManager(BaseConfigManager):
         for i in range(len(self.config)):
             tmp_config = self.config[i]
 
-            if tmp_config['name'] == name:
+            if tmp_config["name"] == name:
                 # pop the current config
                 found_match = True
-        
+
                 return found_match, i
         return False, None
-        
+
     def add_remote(self, update: bool = False, **data_config):
         """add an asset to data config"""
 
-        if data_config.get('path', None) is None:
+        if data_config.get("path", None) is None:
             self.ask_for_remote_path()
 
-        found_match, i = self.check_if_asset_exists(
-            name=data_config.get('name')
-        )
+        found_match, i = self.check_if_asset_exists(name=data_config.get("name"))
 
-        if (update==False) and found_match:
-            logger.error("remote already exists. Check your .mldock/config file to view and edit remotes.")
+        if (update == False) and found_match:
+            logger.error(
+                "remote already exists. Check your .mldock/config file to view and edit remotes."
+            )
             exit(0)
         elif update and found_match:
             current_config = self.config.pop(i)
             current_config.update(data_config)
         elif update and (found_match == False):
-            logger.error("remote does not exists. Check your .mldock/config file to view and edit remotes.")
+            logger.error(
+                "remote does not exists. Check your .mldock/config file to view and edit remotes."
+            )
             exit(0)
         else:
             current_config = data_config
@@ -784,22 +825,22 @@ class RemotesConfigManager(BaseConfigManager):
         self.config.append(data_config)
 
     def remove(self, **data_config):
-        found_match, i = self.check_if_asset_exists(
-            channel=data_config['name']
-        )
+        found_match, i = self.check_if_asset_exists(channel=data_config["name"])
 
         if found_match:
             self.config.pop(i)
         else:
-            logger.error("remote does not exists. Check your .mldock/config file to view and edit remotes.")
+            logger.error(
+                "remote does not exists. Check your .mldock/config file to view and edit remotes."
+            )
 
     def get(self, **data_config):
-        found_match, i = self.check_if_asset_exists(
-            name=data_config['name']
-        )
+        found_match, i = self.check_if_asset_exists(name=data_config["name"])
 
         if found_match:
             return self.config[i]
         else:
-            logger.error("remote does not exists. Check your .mldock/config file to view and edit remotes.")
+            logger.error(
+                "remote does not exists. Check your .mldock/config file to view and edit remotes."
+            )
             exit(0)
