@@ -10,6 +10,7 @@ import io
 from PIL import Image
 import numpy as np
 
+
 def image_to_numpy(image_bytes, convert: str = None):
     """Convert an image bytes string into numpy through PIL.
     Args:
@@ -18,9 +19,7 @@ def image_to_numpy(image_bytes, convert: str = None):
     Returns:
         (np.array): Converted numpy array.
     """
-    pillow_image =  Image.open(
-        io.BytesIO(image_bytes)
-    )
+    pillow_image = Image.open(io.BytesIO(image_bytes))
     if convert is not None:
         pillow_image = pillow_image.convert(convert)
     return np.asarray(pillow_image)
